"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasePartialBatchProcessor = void 0;
const BasePartialProcessor_1 = require("./BasePartialProcessor");
const constants_1 = require("./constants");
const errors_1 = require("./errors");
class BasePartialBatchProcessor extends BasePartialProcessor_1.BasePartialProcessor {
    constructor(eventType) {
        super();
        this.eventType = eventType;
        this.batchResponse = constants_1.DEFAULT_RESPONSE;
        this.COLLECTOR_MAPPING = {
            [constants_1.EventType.SQS]: () => this.collectSqsFailures(),
            [constants_1.EventType.KinesisDataStreams]: () => this.collectKinesisFailures(),
            [constants_1.EventType.DynamoDBStreams]: () => this.collectDynamoDBFailures(),
        };
    }
    clean() {
        if (!this.hasMessagesToReport()) {
            return;
        }
        if (this.entireBatchFailed()) {
            throw new errors_1.FullBatchFailureError(this.errors);
        }
        const messages = this.getMessagesToReport();
        this.batchResponse = { batchItemFailures: messages };
    }
    collectDynamoDBFailures() {
        const failures = [];
        for (const msg of this.failureMessages) {
            const msgId = msg.dynamodb?.SequenceNumber;
            if (msgId) {
                failures.push({ itemIdentifier: msgId });
            }
        }
        return failures;
    }
    collectKinesisFailures() {
        const failures = [];
        for (const msg of this.failureMessages) {
            const msgId = msg.kinesis.sequenceNumber;
            failures.push({ itemIdentifier: msgId });
        }
        return failures;
    }
    collectSqsFailures() {
        const failures = [];
        for (const msg of this.failureMessages) {
            const msgId = msg.messageId;
            failures.push({ itemIdentifier: msgId });
        }
        return failures;
    }
    entireBatchFailed() {
        return this.errors.length == this.records.length;
    }
    getMessagesToReport() {
        return this.COLLECTOR_MAPPING[this.eventType]();
    }
    hasMessagesToReport() {
        return this.failureMessages.length != 0;
    }
    prepare() {
        this.successMessages.length = 0;
        this.failureMessages.length = 0;
        this.errors.length = 0;
        this.batchResponse = constants_1.DEFAULT_RESPONSE;
    }
    response() {
        return this.batchResponse;
    }
    toBatchType(record, eventType) {
        return constants_1.DATA_CLASS_MAPPING[eventType](record);
    }
}
exports.BasePartialBatchProcessor = BasePartialBatchProcessor;
