"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasePartialProcessor = void 0;
class BasePartialProcessor {
    constructor() {
        this.successMessages = [];
        this.failureMessages = [];
        this.errors = [];
        this.records = [];
        this.handler = new Function();
    }
    failureHandler(record, exception) {
        const entry = ['fail', exception.message, record];
        this.errors.push(exception);
        this.failureMessages.push(record);
        return entry;
    }
    async process() {
        if (this.constructor.name === 'BatchProcessorSync') {
            await this.processRecord(this.records[0]);
        }
        this.prepare();
        const processingPromises = this.records.map((record) => this.processRecord(record));
        const processedRecords = await Promise.all(processingPromises);
        this.clean();
        return processedRecords;
    }
    processSync() {
        if (this.constructor.name === 'BatchProcessor') {
            this.processRecordSync(this.records[0]);
        }
        this.prepare();
        const processedRecords = [];
        for (const record of this.records) {
            processedRecords.push(this.processRecordSync(record));
        }
        this.clean();
        return processedRecords;
    }
    register(records, handler, options) {
        this.records = records;
        this.handler = handler;
        if (options) {
            this.options = options;
        }
        return this;
    }
    successHandler(record, result) {
        const entry = ['success', result, record];
        this.successMessages.push(record);
        return entry;
    }
}
exports.BasePartialProcessor = BasePartialProcessor;
