"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqsFifoPartialProcessor = void 0;
const BatchProcessorSync_1 = require("./BatchProcessorSync");
const constants_1 = require("./constants");
const errors_1 = require("./errors");
class SqsFifoPartialProcessor extends BatchProcessorSync_1.BatchProcessorSync {
    constructor() {
        super(constants_1.EventType.SQS);
    }
    processSync() {
        this.prepare();
        const processedRecords = [];
        let currentIndex = 0;
        for (const record of this.records) {
            if (this.failureMessages.length != 0) {
                return this.shortCircuitProcessing(currentIndex, processedRecords);
            }
            processedRecords.push(this.processRecordSync(record));
            currentIndex++;
        }
        this.clean();
        return processedRecords;
    }
    shortCircuitProcessing(firstFailureIndex, processedRecords) {
        const remainingRecords = this.records.slice(firstFailureIndex);
        for (const record of remainingRecords) {
            const data = this.toBatchType(record, this.eventType);
            processedRecords.push(this.failureHandler(data, new errors_1.SqsFifoShortCircuitError()));
        }
        this.clean();
        return processedRecords;
    }
}
exports.SqsFifoPartialProcessor = SqsFifoPartialProcessor;
