"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnexpectedBatchTypeError = exports.SqsFifoShortCircuitError = exports.FullBatchFailureError = exports.BatchProcessingError = void 0;
const constants_1 = require("./constants");
class BatchProcessingError extends Error {
    constructor(message) {
        super(message);
        this.name = 'BatchProcessingError';
    }
}
exports.BatchProcessingError = BatchProcessingError;
class FullBatchFailureError extends BatchProcessingError {
    constructor(childErrors) {
        super('All records failed processing. See individual errors below.');
        this.recordErrors = childErrors;
        this.name = 'FullBatchFailureError';
    }
}
exports.FullBatchFailureError = FullBatchFailureError;
class SqsFifoShortCircuitError extends BatchProcessingError {
    constructor() {
        super('A previous record failed processing. The remaining records were not processed to avoid out-of-order delivery.');
        this.name = 'SqsFifoShortCircuitError';
    }
}
exports.SqsFifoShortCircuitError = SqsFifoShortCircuitError;
class UnexpectedBatchTypeError extends BatchProcessingError {
    constructor() {
        super(`Unexpected batch type. Possible values are: ${Object.values(constants_1.EventType).join(', ')}`);
        this.name = 'UnexpectedBatchTypeError';
    }
}
exports.UnexpectedBatchTypeError = UnexpectedBatchTypeError;
